#!/bin/sh

###############################################################
#   This script has effect only on DSM7-0 or later
#   This script should be hooked when share is being unmounted / encrypted
#   Usable environment variable:
#       SHARE_NAME, MOUNT_ACTION={unmount|mount}, RESULT
###############################################################

#At begining, acquire package settings
FILEINDEX_TOOL_PATH=/var/packages/SynoFinder/target/tool/fileindex

PKG_NAME="SynoFinder"
PKG_VERSION="1.0"
PKG_VENDOR="Synology Inc."
SDK_MODVER="2.0"

case $1 in
	--sdk-mod-ver)
		#Print SDK support version
		echo ${SDK_MODVER}
	;;
	--name)
		#Print package name
		echo ${PKG_NAME}
	;;
	--pkg-ver)
		#Print package version
		echo ${PKG_VERSION}
	;;
	--vendor)
		#Print package vendor
		echo ${PKG_VENDOR}
	;;
	--pre)
		#Actions before share unmount action
		if [ "unmount" = "${MOUNT_ACTION}" ]; then # encryption / c2 unmount
			${FILEINDEX_TOOL_PATH} -a share_pause  -n "${SHARE_NAME}" -d "share_mount_action unmount pre: share_pause"
		fi
	;;
	--post)
		#Actions after share unmount action
		if [ "unmount" = "${MOUNT_ACTION}" ] && [ "0" != "${RESULT}" ]; then # failed unmounting
			${FILEINDEX_TOOL_PATH} -a share_resume -n "${SHARE_NAME}" -d "share_mount_action unmount post: share_resume"
		elif [ "mount" = "${MOUNT_ACTION}" ] && [ "0" = "${RESULT}" ]; then # succeed mounting
			${FILEINDEX_TOOL_PATH} -a share_resume -n "${SHARE_NAME}" -d "share_mount_action mount post: share_resume"
			${FILEINDEX_TOOL_PATH} -a share_autoclean -n "${SHARE_NAME}" -d "share_mount_action mount post: share_autoclean"
		fi
	;;
	*)
		echo "Usage: $0 --sdk-mod-ver|--name|--pkg-ver|--vendor|--pre|--post"
	;;
esac

exit 0